@@ -21,9 +21,9 @@ T = TypeVar("T")
 EnumT = TypeVar("EnumT", bound=Enum)
 
 
-def from_float(x: Any) -> float:
-    assert isinstance(x, (float, int)) and not isinstance(x, bool)
-    return float(x)
+def from_str(x: Any) -> str:
+    assert isinstance(x, str)
+    return x
 
 
 def from_none(x: Any) -> Any:
@@ -40,20 +40,25 @@ def from_union(fs, x):
     assert False
 
 
+def from_float(x: Any) -> float:
+    assert isinstance(x, (float, int)) and not isinstance(x, bool)
+    return float(x)
+
+
 def to_float(x: Any) -> float:
     assert isinstance(x, float)
     return x
 
 
+def from_list(f: Callable[[Any], T], x: Any) -> List[T]:
+    assert isinstance(x, list)
+    return [f(y) for y in x]
+
+
 def from_datetime(x: Any) -> datetime:
     return dateutil.parser.parse(x)
 
 
-def from_str(x: Any) -> str:
-    assert isinstance(x, str)
-    return x
-
-
 def from_bool(x: Any) -> bool:
     assert isinstance(x, bool)
     return x
@@ -69,13 +74,9 @@ def to_enum(c: Type[EnumT], x: Any) -> EnumT:
     return x.value
 
 
-def from_list(f: Callable[[Any], T], x: Any) -> List[T]:
-    assert isinstance(x, list)
-    return [f(y) for y in x]
-
-
 class AspectType(Enum):
     DASHBOARD_INFO = "DASHBOARD_INFO"
+    DASHBOARD_UPSTREAM = "DASHBOARD_UPSTREAM"
     DATASET_COMMENT = "DATASET_COMMENT"
     DATASET_DOCUMENTATION = "DATASET_DOCUMENTATION"
     DATASET_DOWNSTREAM = "DATASET_DOWNSTREAM"
@@ -90,6 +91,22 @@ class AspectType(Enum):
     PROPERTIES = "PROPERTIES"
 
 
+@dataclass
+class Chart:
+    title: Optional[str] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'Chart':
+        assert isinstance(obj, dict)
+        title = from_union([from_str, from_none], obj.get("title"))
+        return Chart(title)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["title"] = from_union([from_str, from_none], self.title)
+        return result
+
+
 @dataclass
 class ObjectID:
     """A class representation of the BSON ObjectId type."""
@@ -112,36 +129,45 @@ class ObjectID:
 class DashboardInfo:
     id: Optional[ObjectID] = None
     aspect_type: Optional[AspectType] = None
+    charts: Optional[List[Chart]] = None
     created_at: Optional[datetime] = None
     description: Optional[str] = None
     entity_id: Optional[str] = None
     dashboard_info_id: Optional[str] = None
     latest: Optional[bool] = None
     title: Optional[str] = None
+    url: Optional[str] = None
+    view_count: Optional[float] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'DashboardInfo':
         assert isinstance(obj, dict)
         id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
         aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
+        charts = from_union([lambda x: from_list(Chart.from_dict, x), from_none], obj.get("charts"))
         created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
         description = from_union([from_str, from_none], obj.get("description"))
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         dashboard_info_id = from_union([from_str, from_none], obj.get("id"))
         latest = from_union([from_bool, from_none], obj.get("latest"))
         title = from_union([from_str, from_none], obj.get("title"))
-        return DashboardInfo(id, aspect_type, created_at, description, entity_id, dashboard_info_id, latest, title)
+        url = from_union([from_str, from_none], obj.get("url"))
+        view_count = from_union([from_float, from_none], obj.get("viewCount"))
+        return DashboardInfo(id, aspect_type, charts, created_at, description, entity_id, dashboard_info_id, latest, title, url, view_count)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
         result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
+        result["charts"] = from_union([lambda x: from_list(lambda x: to_class(Chart, x), x), from_none], self.charts)
         result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
         result["description"] = from_union([from_str, from_none], self.description)
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["id"] = from_union([from_str, from_none], self.dashboard_info_id)
         result["latest"] = from_union([from_bool, from_none], self.latest)
         result["title"] = from_union([from_str, from_none], self.title)
+        result["url"] = from_union([from_str, from_none], self.url)
+        result["viewCount"] = from_union([to_float, from_none], self.view_count)
         return result
 
 
@@ -183,6 +209,81 @@ class DashboardLogicalID:
         return result
 
 
+class DataPlatform(Enum):
+    DOCUMENTDB = "DOCUMENTDB"
+    DYNAMODB = "DYNAMODB"
+    ELASTICSEARCH = "ELASTICSEARCH"
+    LOOKER = "LOOKER"
+    MYSQL = "MYSQL"
+    POSTGRESQL = "POSTGRESQL"
+    RDS = "RDS"
+    REDIS = "REDIS"
+    REDSHIFT = "REDSHIFT"
+    S3 = "S3"
+    SNOWFLAKE = "SNOWFLAKE"
+    UNKNOWN = "UNKNOWN"
+
+
+@dataclass
+class DatasetLogicalID:
+    """Identify an entity "logically", besides the system generated UUID.
+    Each entity must have a logicalId to be ingested.
+    A compelling use-case is that this allows a producer to create an
+    instance of the Entity without requiring a unique UUID to be
+    obtained prior to instantiation, potentially resulting in two round-trips
+    """
+    name: Optional[str] = None
+    platform: Optional[DataPlatform] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'DatasetLogicalID':
+        assert isinstance(obj, dict)
+        name = from_union([from_str, from_none], obj.get("name"))
+        platform = from_union([DataPlatform, from_none], obj.get("platform"))
+        return DatasetLogicalID(name, platform)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["name"] = from_union([from_str, from_none], self.name)
+        result["platform"] = from_union([lambda x: to_enum(DataPlatform, x), from_none], self.platform)
+        return result
+
+
+@dataclass
+class DashboardUpstream:
+    """DashboardUpstream captures upstream lineages from data sources to this dashboard"""
+    id: Optional[ObjectID] = None
+    aspect_type: Optional[AspectType] = None
+    created_at: Optional[datetime] = None
+    entity_id: Optional[str] = None
+    dashboard_upstream_id: Optional[str] = None
+    latest: Optional[bool] = None
+    sources: Optional[List[DatasetLogicalID]] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'DashboardUpstream':
+        assert isinstance(obj, dict)
+        id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
+        aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
+        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        entity_id = from_union([from_str, from_none], obj.get("entityId"))
+        dashboard_upstream_id = from_union([from_str, from_none], obj.get("id"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
+        sources = from_union([lambda x: from_list(DatasetLogicalID.from_dict, x), from_none], obj.get("sources"))
+        return DashboardUpstream(id, aspect_type, created_at, entity_id, dashboard_upstream_id, latest, sources)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
+        result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["entityId"] = from_union([from_str, from_none], self.entity_id)
+        result["id"] = from_union([from_str, from_none], self.dashboard_upstream_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
+        result["sources"] = from_union([lambda x: from_list(lambda x: to_class(DatasetLogicalID, x), x), from_none], self.sources)
+        return result
+
+
 @dataclass
 class Dashboard:
     created_at: Optional[datetime] = None
@@ -198,6 +299,8 @@ class Dashboard:
     obtained prior to instantiation, potentially resulting in two round-trips
     """
     logical_id: Optional[DashboardLogicalID] = None
+    """DashboardUpstream captures upstream lineages from data sources to this dashboard"""
+    upstream: Optional[DashboardUpstream] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'Dashboard':
@@ -209,7 +312,8 @@ class Dashboard:
         id = from_union([from_str, from_none], obj.get("id"))
         last_modified_at = from_union([from_datetime, from_none], obj.get("lastModifiedAt"))
         logical_id = from_union([DashboardLogicalID.from_dict, from_none], obj.get("logicalId"))
-        return Dashboard(created_at, dashboard_info, deleted_at, entity_type, id, last_modified_at, logical_id)
+        upstream = from_union([DashboardUpstream.from_dict, from_none], obj.get("upstream"))
+        return Dashboard(created_at, dashboard_info, deleted_at, entity_type, id, last_modified_at, logical_id, upstream)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -220,6 +324,7 @@ class Dashboard:
         result["id"] = from_union([from_str, from_none], self.id)
         result["lastModifiedAt"] = from_union([lambda x: x.isoformat(), from_none], self.last_modified_at)
         result["logicalId"] = from_union([lambda x: to_class(DashboardLogicalID, x), from_none], self.logical_id)
+        result["upstream"] = from_union([lambda x: to_class(DashboardUpstream, x), from_none], self.upstream)
         return result
 
 
@@ -347,46 +452,6 @@ class DatasetDocumentation:
         return result
 
 
-class DataPlatform(Enum):
-    DOCUMENTDB = "DOCUMENTDB"
-    DYNAMODB = "DYNAMODB"
-    ELASTICSEARCH = "ELASTICSEARCH"
-    LOOKER = "LOOKER"
-    MYSQL = "MYSQL"
-    POSTGRESQL = "POSTGRESQL"
-    RDS = "RDS"
-    REDIS = "REDIS"
-    REDSHIFT = "REDSHIFT"
-    S3 = "S3"
-    SNOWFLAKE = "SNOWFLAKE"
-    UNKNOWN = "UNKNOWN"
-
-
-@dataclass
-class DatasetLogicalID:
-    """Identify an entity "logically", besides the system generated UUID.
-    Each entity must have a logicalId to be ingested.
-    A compelling use-case is that this allows a producer to create an
-    instance of the Entity without requiring a unique UUID to be
-    obtained prior to instantiation, potentially resulting in two round-trips
-    """
-    name: Optional[str] = None
-    platform: Optional[DataPlatform] = None
-
-    @staticmethod
-    def from_dict(obj: Any) -> 'DatasetLogicalID':
-        assert isinstance(obj, dict)
-        name = from_union([from_str, from_none], obj.get("name"))
-        platform = from_union([DataPlatform, from_none], obj.get("platform"))
-        return DatasetLogicalID(name, platform)
-
-    def to_dict(self) -> dict:
-        result: dict = {}
-        result["name"] = from_union([from_str, from_none], self.name)
-        result["platform"] = from_union([lambda x: to_enum(DataPlatform, x), from_none], self.platform)
-        return result
-
-
 @dataclass
 class DatasetDownstream:
     """DatasetDownstream captures downstream lineages from this dataset"""
@@ -1036,28 +1101,141 @@ class Group:
         return result
 
 
+@dataclass
+class Input:
+    created: Optional[datetime] = None
+    name: Optional[str] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'Input':
+        assert isinstance(obj, dict)
+        created = from_union([from_datetime, from_none], obj.get("created"))
+        name = from_union([from_str, from_none], obj.get("name"))
+        return Input(created, name)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["created"] = from_union([lambda x: x.isoformat(), from_none], self.created)
+        result["name"] = from_union([from_str, from_none], self.name)
+        return result
+
+
+@dataclass
+class PersonEditableInfo:
+    id: Optional[ObjectID] = None
+    aspect_type: Optional[AspectType] = None
+    created_at: Optional[datetime] = None
+    entity_id: Optional[str] = None
+    person_editable_info_id: Optional[str] = None
+    latest: Optional[bool] = None
+    skills: Optional[List[Input]] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'PersonEditableInfo':
+        assert isinstance(obj, dict)
+        id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
+        aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
+        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        entity_id = from_union([from_str, from_none], obj.get("entityId"))
+        person_editable_info_id = from_union([from_str, from_none], obj.get("id"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
+        skills = from_union([lambda x: from_list(Input.from_dict, x), from_none], obj.get("skills"))
+        return PersonEditableInfo(id, aspect_type, created_at, entity_id, person_editable_info_id, latest, skills)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
+        result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["entityId"] = from_union([from_str, from_none], self.entity_id)
+        result["id"] = from_union([from_str, from_none], self.person_editable_info_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
+        result["skills"] = from_union([lambda x: from_list(lambda x: to_class(Input, x), x), from_none], self.skills)
+        return result
+
+
+@dataclass
+class PersonOrganization:
+    id: Optional[ObjectID] = None
+    aspect_type: Optional[AspectType] = None
+    created_at: Optional[datetime] = None
+    department: Optional[str] = None
+    division: Optional[str] = None
+    employee_number: Optional[str] = None
+    entity_id: Optional[str] = None
+    groups: Optional[List[GroupID]] = None
+    person_organization_id: Optional[str] = None
+    latest: Optional[bool] = None
+    manager: Optional[PersonID] = None
+    manager_id: Optional[str] = None
+    manager_name: Optional[str] = None
+    name: Optional[str] = None
+    title: Optional[str] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'PersonOrganization':
+        assert isinstance(obj, dict)
+        id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
+        aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
+        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        department = from_union([from_str, from_none], obj.get("department"))
+        division = from_union([from_str, from_none], obj.get("division"))
+        employee_number = from_union([from_str, from_none], obj.get("employeeNumber"))
+        entity_id = from_union([from_str, from_none], obj.get("entityId"))
+        groups = from_union([lambda x: from_list(GroupID.from_dict, x), from_none], obj.get("groups"))
+        person_organization_id = from_union([from_str, from_none], obj.get("id"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
+        manager = from_union([PersonID.from_dict, from_none], obj.get("manager"))
+        manager_id = from_union([from_str, from_none], obj.get("managerId"))
+        manager_name = from_union([from_str, from_none], obj.get("managerName"))
+        name = from_union([from_str, from_none], obj.get("name"))
+        title = from_union([from_str, from_none], obj.get("title"))
+        return PersonOrganization(id, aspect_type, created_at, department, division, employee_number, entity_id, groups, person_organization_id, latest, manager, manager_id, manager_name, name, title)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
+        result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["department"] = from_union([from_str, from_none], self.department)
+        result["division"] = from_union([from_str, from_none], self.division)
+        result["employeeNumber"] = from_union([from_str, from_none], self.employee_number)
+        result["entityId"] = from_union([from_str, from_none], self.entity_id)
+        result["groups"] = from_union([lambda x: from_list(lambda x: to_class(GroupID, x), x), from_none], self.groups)
+        result["id"] = from_union([from_str, from_none], self.person_organization_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
+        result["manager"] = from_union([lambda x: to_class(PersonID, x), from_none], self.manager)
+        result["managerId"] = from_union([from_str, from_none], self.manager_id)
+        result["managerName"] = from_union([from_str, from_none], self.manager_name)
+        result["name"] = from_union([from_str, from_none], self.name)
+        result["title"] = from_union([from_str, from_none], self.title)
+        return result
+
+
 @dataclass
 class PersonProperties:
+    """Object / output type for PersonProperties aspect contains the full aspect fields
+    
+    Input type for PersonProperties aspect, contains just the common fields across input and
+    output
+    """
     id: Optional[ObjectID] = None
     aspect_type: Optional[AspectType] = None
     avatar_url: Optional[str] = None
     created_at: Optional[datetime] = None
-    department: Optional[str] = None
     display_name: Optional[str] = None
-    division: Optional[str] = None
-    employee_number: Optional[str] = None
     entity_id: Optional[str] = None
     first_name: Optional[str] = None
+    full_name: Optional[str] = None
     person_properties_id: Optional[str] = None
+    issuer: Optional[str] = None
     last_login: Optional[str] = None
     last_name: Optional[str] = None
     latest: Optional[bool] = None
-    manager: Optional[str] = None
-    manager_id: Optional[str] = None
     mobile_phone: Optional[str] = None
     occupation: Optional[str] = None
-    organization: Optional[str] = None
     primary_phone: Optional[str] = None
+    provider_name: Optional[str] = None
     status: Optional[str] = None
     title: Optional[str] = None
 
@@ -1068,25 +1246,22 @@ class PersonProperties:
         aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
         avatar_url = from_union([from_str, from_none], obj.get("avatarUrl"))
         created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
-        department = from_union([from_str, from_none], obj.get("department"))
         display_name = from_union([from_str, from_none], obj.get("displayName"))
-        division = from_union([from_str, from_none], obj.get("division"))
-        employee_number = from_union([from_str, from_none], obj.get("employeeNumber"))
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         first_name = from_union([from_str, from_none], obj.get("firstName"))
+        full_name = from_union([from_str, from_none], obj.get("fullName"))
         person_properties_id = from_union([from_str, from_none], obj.get("id"))
+        issuer = from_union([from_str, from_none], obj.get("issuer"))
         last_login = from_union([from_str, from_none], obj.get("lastLogin"))
         last_name = from_union([from_str, from_none], obj.get("lastName"))
         latest = from_union([from_bool, from_none], obj.get("latest"))
-        manager = from_union([from_str, from_none], obj.get("manager"))
-        manager_id = from_union([from_str, from_none], obj.get("managerId"))
         mobile_phone = from_union([from_str, from_none], obj.get("mobilePhone"))
         occupation = from_union([from_str, from_none], obj.get("occupation"))
-        organization = from_union([from_str, from_none], obj.get("organization"))
         primary_phone = from_union([from_str, from_none], obj.get("primaryPhone"))
+        provider_name = from_union([from_str, from_none], obj.get("providerName"))
         status = from_union([from_str, from_none], obj.get("status"))
         title = from_union([from_str, from_none], obj.get("title"))
-        return PersonProperties(id, aspect_type, avatar_url, created_at, department, display_name, division, employee_number, entity_id, first_name, person_properties_id, last_login, last_name, latest, manager, manager_id, mobile_phone, occupation, organization, primary_phone, status, title)
+        return PersonProperties(id, aspect_type, avatar_url, created_at, display_name, entity_id, first_name, full_name, person_properties_id, issuer, last_login, last_name, latest, mobile_phone, occupation, primary_phone, provider_name, status, title)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -1094,22 +1269,19 @@ class PersonProperties:
         result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
         result["avatarUrl"] = from_union([from_str, from_none], self.avatar_url)
         result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
-        result["department"] = from_union([from_str, from_none], self.department)
         result["displayName"] = from_union([from_str, from_none], self.display_name)
-        result["division"] = from_union([from_str, from_none], self.division)
-        result["employeeNumber"] = from_union([from_str, from_none], self.employee_number)
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["firstName"] = from_union([from_str, from_none], self.first_name)
+        result["fullName"] = from_union([from_str, from_none], self.full_name)
         result["id"] = from_union([from_str, from_none], self.person_properties_id)
+        result["issuer"] = from_union([from_str, from_none], self.issuer)
         result["lastLogin"] = from_union([from_str, from_none], self.last_login)
         result["lastName"] = from_union([from_str, from_none], self.last_name)
         result["latest"] = from_union([from_bool, from_none], self.latest)
-        result["manager"] = from_union([from_str, from_none], self.manager)
-        result["managerId"] = from_union([from_str, from_none], self.manager_id)
         result["mobilePhone"] = from_union([from_str, from_none], self.mobile_phone)
         result["occupation"] = from_union([from_str, from_none], self.occupation)
-        result["organization"] = from_union([from_str, from_none], self.organization)
         result["primaryPhone"] = from_union([from_str, from_none], self.primary_phone)
+        result["providerName"] = from_union([from_str, from_none], self.provider_name)
         result["status"] = from_union([from_str, from_none], self.status)
         result["title"] = from_union([from_str, from_none], self.title)
         return result
@@ -1124,6 +1296,7 @@ class Person:
     avatar_url: Optional[str] = None
     created_at: Optional[datetime] = None
     deleted_at: Optional[datetime] = None
+    editable_info: Optional[PersonEditableInfo] = None
     entity_type: Optional[EntityType] = None
     first_name: Optional[str] = None
     id: Optional[str] = None
@@ -1136,6 +1309,7 @@ class Person:
     obtained prior to instantiation, potentially resulting in two round-trips
     """
     logical_id: Optional[PersonID] = None
+    organization: Optional[PersonOrganization] = None
     password: Optional[str] = None
     properties: Optional[PersonProperties] = None
 
@@ -1145,27 +1319,31 @@ class Person:
         avatar_url = from_union([from_str, from_none], obj.get("avatarUrl"))
         created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
         deleted_at = from_union([from_datetime, from_none], obj.get("deletedAt"))
+        editable_info = from_union([PersonEditableInfo.from_dict, from_none], obj.get("editableInfo"))
         entity_type = from_union([EntityType, from_none], obj.get("entityType"))
         first_name = from_union([from_str, from_none], obj.get("firstName"))
         id = from_union([from_str, from_none], obj.get("id"))
         last_modified_at = from_union([from_datetime, from_none], obj.get("lastModifiedAt"))
         last_name = from_union([from_str, from_none], obj.get("lastName"))
         logical_id = from_union([PersonID.from_dict, from_none], obj.get("logicalId"))
+        organization = from_union([PersonOrganization.from_dict, from_none], obj.get("organization"))
         password = from_union([from_str, from_none], obj.get("password"))
         properties = from_union([PersonProperties.from_dict, from_none], obj.get("properties"))
-        return Person(avatar_url, created_at, deleted_at, entity_type, first_name, id, last_modified_at, last_name, logical_id, password, properties)
+        return Person(avatar_url, created_at, deleted_at, editable_info, entity_type, first_name, id, last_modified_at, last_name, logical_id, organization, password, properties)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["avatarUrl"] = from_union([from_str, from_none], self.avatar_url)
         result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
         result["deletedAt"] = from_union([lambda x: x.isoformat(), from_none], self.deleted_at)
+        result["editableInfo"] = from_union([lambda x: to_class(PersonEditableInfo, x), from_none], self.editable_info)
         result["entityType"] = from_union([lambda x: to_enum(EntityType, x), from_none], self.entity_type)
         result["firstName"] = from_union([from_str, from_none], self.first_name)
         result["id"] = from_union([from_str, from_none], self.id)
         result["lastModifiedAt"] = from_union([lambda x: x.isoformat(), from_none], self.last_modified_at)
         result["lastName"] = from_union([from_str, from_none], self.last_name)
         result["logicalId"] = from_union([lambda x: to_class(PersonID, x), from_none], self.logical_id)
+        result["organization"] = from_union([lambda x: to_class(PersonOrganization, x), from_none], self.organization)
         result["password"] = from_union([from_str, from_none], self.password)
         result["properties"] = from_union([lambda x: to_class(PersonProperties, x), from_none], self.properties)
         return result
