@@ -109,8 +109,16 @@ class PostgresqlExtractor(BaseExtractor):
         self, conn, platform: DataPlatform
     ) -> List[Tuple[str, str, str]]:
         results = await conn.fetch(
-            "SELECT table_catalog, table_schema, table_name, table_type "
-            "FROM information_schema.tables "
+            "SELECT table_catalog, table_schema, table_name, table_type, pgd.description "
+            "FROM information_schema.tables t "
+            "LEFT JOIN pg_catalog.pg_description pgd "
+            "  ON pgd.objoid = ( "
+            "      SELECT oid FROM pg_class "
+            "      WHERE relname = t.table_name "
+            "        AND relnamespace = ( "
+            "            SELECT oid FROM pg_catalog.pg_namespace WHERE nspname = t.table_schema "
+            "          ) "
+            "        ) AND pgd.objsubid = 0 "
             "WHERE table_schema != 'pg_catalog' AND table_schema != 'information_schema' "
             "ORDER BY table_schema, table_name"
         )
@@ -121,9 +129,10 @@ class PostgresqlExtractor(BaseExtractor):
             schema = table["table_schema"]
             name = table["table_name"]
             table_type = table["table_type"]
+            description = table["description"]
             full_name = self._dataset_name(catalog, schema, name)
             self._datasets[full_name] = self._init_dataset(
-                full_name, table_type, platform
+                full_name, table_type, platform, description
             )
             tables.append((schema, name, full_name))
 
@@ -186,7 +195,7 @@ class PostgresqlExtractor(BaseExtractor):
 
     @staticmethod
     def _init_dataset(
-        full_name: str, table_type: str, platform: DataPlatform
+        full_name: str, table_type: str, platform: DataPlatform, description: str
     ) -> Dataset:
         dataset = Dataset()
         dataset.entity_type = EntityType.DATASET
@@ -197,6 +206,7 @@ class PostgresqlExtractor(BaseExtractor):
         dataset.schema = DatasetSchema()
         dataset.schema.aspect_type = AspectType.DATASET_SCHEMA
         dataset.schema.schema_type = SchemaType.SQL
+        dataset.schema.description = description
         dataset.schema.fields = []
         dataset.schema.sql_schema = SQLSchema()
         dataset.schema.sql_schema.materialization = (
