@@ -1,10 +1,13 @@
 try:
-    import unzip_requirements
+    import unzip_requirements  # noqa: F401
 except ImportError:
     pass
 
 from metaphor.common.handler import handle_api
-from metaphor.snowflake_extractor import SnowflakeExtractor, SnowflakeRunConfig
+from metaphor.snowflake_extractor.extractor import (
+    SnowflakeExtractor,
+    SnowflakeRunConfig,
+)
 
 
 def handle(event, context):
